@@ -137,9 +137,11 @@ pub struct Subclass {
     pub subclass: Ident,
 }
 
+#[derive(Clone)]
 pub struct RustFun {
     pub path: RustPath,
     pub sig: Signature,
+    pub receiver: Option<Ident>,
 }
 
 impl std::fmt::Debug for RustFun {
@@ -288,7 +290,11 @@ impl Parse for IncludeCppConfig {
                     let path: RustPath = args.parse()?;
                     args.parse::<syn::token::Comma>()?;
                     let sig: syn::Signature = args.parse()?;
-                    extern_rust_funs.push(RustFun { path, sig });
+                    extern_rust_funs.push(RustFun {
+                        path,
+                        sig,
+                        receiver: None,
+                    });
                 } else {
                     return Err(syn::Error::new(
                         ident.span(),
@@ -510,19 +516,9 @@ impl IncludeCppConfig {
         )
     }
 
-    pub fn confirm_complete(&mut self, auto_allowlist: bool) -> ParseResult<()> {
+    pub fn confirm_complete(&mut self) {
         if matches!(self.allowlist, Allowlist::Unspecified(_)) {
-            if auto_allowlist {
-                self.allowlist = Allowlist::Specific(Vec::new());
-                Ok(())
-            } else {
-                Err(syn::Error::new(
-                    Span::call_site(),
-                    "expected either generate!/generate_ns! or generate_all!",
-                ))
-            }
-        } else {
-            Ok(())
+            self.allowlist = Allowlist::Specific(Vec::new());
         }
     }
 
